@@ -8,19 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_cloudfront._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.aws_ssm._jsii
-import aws_cdk.core._jsii
-import aws_cdk.custom_resources._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-lambda-at-edge-pattern",
-    "1.47.0",
+    "2.1.0",
     __name__[0:-6],
-    "cdk-lambda-at-edge-pattern@1.47.0.jsii.tgz",
+    "cdk-lambda-at-edge-pattern@2.1.0.jsii.tgz",
 )
 
 __all__ = [
